==> haskell-xss-sanitize-0.3.5.7-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.7
id: xss-sanitize-0.3.5.7-52sK2IstXftHMu6Gfxxz0d
key: xss-sanitize-0.3.5.7-52sK2IstXftHMu6Gfxxz0d
license: BSD2
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
abi: 64bc2c9ec599bfc3849f8783bed1780b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/xss-sanitize-0.3.5.7
hs-libraries: HSxss-sanitize-0.3.5.7-52sK2IstXftHMu6Gfxxz0d
depends:
    attoparsec-0.13.1.0-A4pUaeqQWkyDZOYwXw4PvN base-4.9.0.0
    containers-0.5.7.1 css-text-0.1.2.2-76Y9GEOrK8i48IkycRICtF
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    tagsoup-0.14.1-KYZUR9e2g1HF7Iyx7P13Y8
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.5.7-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xss-sanitize
version: 0.3.5.7
id: xss-sanitize-0.3.5.7-Enknq3BFf90DHjL4gDzDUx
key: xss-sanitize-0.3.5.7-Enknq3BFf90DHjL4gDzDUx
license: BSD2
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://github.com/yesodweb/haskell-xss-sanitize
synopsis: sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details
category: Web
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules:
    Text.HTML.SanitizeXSS
hidden-modules: Text.HTML.SanitizeXSS.Css
abi: 99c11a7f88de18e2f854608e2f71c7be
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/xss-sanitize-0.3.5.7
data-dir: /usr/share/i386-linux-ghc-8.0.1/xss-sanitize-0.3.5.7
hs-libraries: HSxss-sanitize-0.3.5.7-Enknq3BFf90DHjL4gDzDUx
depends:
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    containers-0.5.7.1 css-text-0.1.2.2-ArpsWbLcJEEHqipxbVbJJ3
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    tagsoup-0.14.1-KYZUR9e2g1HF7Iyx7P13Y8
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock
haddock-html: /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
